/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2010 EBM WebSourcing - http://www.petalslink.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

package org.ow2.petals.se.jsr181.model;

import java.net.URL;

/**
 * A bean to store SU elements that can be used at runtime by this component.
 * @author Vincent Zurczak - EBM WebSourcing
 */
public class JaxConfiguration {

	/**
	 * The service URL.
	 */
	private final URL serviceURL;

	/**
	 * The SU root path.
	 */
	private final String suRootPath;

	/**
	 * The class name.
	 */
	private final String className;

	/**
	 * The end-point name.
	 */
	private final String endpointName;

	/**
	 * The service-unit name.
	 */
	private final String serviceUnitName;


	/**
	 * Constructor.
	 * @param serviceURL the service URL
	 * @param suRootPath the SU root path
	 * @param className the class name
	 * @param endpointName the end-point name
	 * @param serviceUnitName the service-unit name
	 */
	public JaxConfiguration(
			URL serviceURL,
			String suRootPath,
			String className,
			String endpointName,
			String serviceUnitName ) {

		this.serviceURL = serviceURL;
		this.suRootPath = suRootPath;
		this.className = className;
		this.endpointName = endpointName;
		this.serviceUnitName = serviceUnitName;
	}


	/**
	 * @return the serviceURL
	 */
	public URL getServiceURL() {
		return this.serviceURL;
	}


	/**
	 * @return the suRootPath
	 */
	public String getSuRootPath() {
		return this.suRootPath;
	}


	/**
	 * @return the className
	 */
	public String getClassName() {
		return this.className;
	}


	/**
	 * @return the endpointName
	 */
	public String getEndpointName() {
		return this.endpointName;
	}


	/**
	 * @return the serviceUnitName
	 */
	public String getServiceUnitName() {
		return this.serviceUnitName;
	}
}
