/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2010 EBM WebSourcing - http://www.petalslink.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

package org.ow2.petals.se.jsr181.utils;

import java.net.URL;
import java.net.URLClassLoader;
import java.security.AccessController;
import java.security.PrivilegedAction;

import org.apache.axis2.classloader.JarFileClassLoader;

/**
 * A class loader that puts all the JARs and the root directory in the class path.
 * <p>
 * This class is a partial copy of org.ow2.petals.se.talend.utils.TalendClassLoaderUtils,
 * except we use a class loader from Axis2 libraries.
 * </p>
 *
 * @author Vincent Zurczak - EBM WebSourcing
 */
public class Jsr181ClassLoaderUtils {

	/**
	 * As all methods of this class are static, no constructor is available.
	 */
	private Jsr181ClassLoaderUtils() {
		// Nothing
	}

	/**
	 * Return an URLClassLoader object, with all Jar contained in the given directory path.
	 * 
	 * @param urls the URLs to load
	 * @param parent the parent class loader to use
	 * @return a classLoader
	 */
	public static URLClassLoader createClassLoader(final URL[] urls, final ClassLoader parent) {
		return AccessController.doPrivileged( new Jsr181ComponentPrivilegedAction( urls, parent ));
	}


	/**
	 * Create a new URL class loader.
	 */
	public static class Jsr181ComponentPrivilegedAction implements PrivilegedAction<URLClassLoader> {

		/**
		 * The URLs to search classes.
		 */
		private URL[] urls = null;

		/**
		 * The parent class loader.
		 */
		private ClassLoader parent = null;

		/**
		 * Constructor.
		 * @param urls the URLs
		 * @param parent the parent class loader
		 */
		public Jsr181ComponentPrivilegedAction( final URL[] urls, final ClassLoader parent ) {
			super();
			this.urls = urls;
			this.parent = parent;
		}

		/*
		 * (non-Javadoc)
		 * @see java.security.PrivilegedAction#run()
		 */
		public URLClassLoader run() {
			return new JarFileClassLoader( this.urls, this.parent );
		}
	}
}
